==> kdev-php-5.4.5-1-x86_64.pkg.tar.xz: usr/lib/cmake/KDevPHP/KDevPHPTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "kdevphpparser" for configuration "Release"
set_property(TARGET kdevphpparser APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(kdevphpparser PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libkdevphpparser.so"
  IMPORTED_SONAME_RELEASE "libkdevphpparser.so"
  )

list(APPEND _IMPORT_CHECK_TARGETS kdevphpparser )
list(APPEND _IMPORT_CHECK_FILES_FOR_kdevphpparser "${_IMPORT_PREFIX}/lib/libkdevphpparser.so" )

# Import target "kdevphpduchain" for configuration "Release"
set_property(TARGET kdevphpduchain APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(kdevphpduchain PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libkdevphpduchain.so"
  IMPORTED_SONAME_RELEASE "libkdevphpduchain.so"
  )

list(APPEND _IMPORT_CHECK_TARGETS kdevphpduchain )
list(APPEND _IMPORT_CHECK_FILES_FOR_kdevphpduchain "${_IMPORT_PREFIX}/lib/libkdevphpduchain.so" )

# Import target "kdevphpcompletion" for configuration "Release"
set_property(TARGET kdevphpcompletion APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(kdevphpcompletion PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libkdevphpcompletion.so"
  IMPORTED_SONAME_RELEASE "libkdevphpcompletion.so"
  )

list(APPEND _IMPORT_CHECK_TARGETS kdevphpcompletion )
list(APPEND _IMPORT_CHECK_FILES_FOR_kdevphpcompletion "${_IMPORT_PREFIX}/lib/libkdevphpcompletion.so" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> kdev-php-5.5.2-1-x86_64.pkg.tar.xz: usr/lib/cmake/KDevPHP/KDevPHPTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "kdevphpparser" for configuration "Release"
set_property(TARGET kdevphpparser APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(kdevphpparser PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDev::Language;KF5::I18n"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libkdevphpparser.so"
  IMPORTED_SONAME_RELEASE "libkdevphpparser.so"
  )

list(APPEND _IMPORT_CHECK_TARGETS kdevphpparser )
list(APPEND _IMPORT_CHECK_FILES_FOR_kdevphpparser "${_IMPORT_PREFIX}/lib/libkdevphpparser.so" )

# Import target "kdevphpduchain" for configuration "Release"
set_property(TARGET kdevphpduchain APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(kdevphpduchain PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDev::Interfaces;KDev::Language;KDev::Shell;KDev::Project;kdevphpparser"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libkdevphpduchain.so"
  IMPORTED_SONAME_RELEASE "libkdevphpduchain.so"
  )

list(APPEND _IMPORT_CHECK_TARGETS kdevphpduchain )
list(APPEND _IMPORT_CHECK_FILES_FOR_kdevphpduchain "${_IMPORT_PREFIX}/lib/libkdevphpduchain.so" )

# Import target "kdevphpcompletion" for configuration "Release"
set_property(TARGET kdevphpcompletion APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(kdevphpcompletion PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDev::Language;KDev::Interfaces;KDev::Project;kdevphpduchain;kdevphpparser"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libkdevphpcompletion.so"
  IMPORTED_SONAME_RELEASE "libkdevphpcompletion.so"
  )

list(APPEND _IMPORT_CHECK_TARGETS kdevphpcompletion )
list(APPEND _IMPORT_CHECK_FILES_FOR_kdevphpcompletion "${_IMPORT_PREFIX}/lib/libkdevphpcompletion.so" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
